@@ -545,7 +545,7 @@ def watch(ctx, output):
     try:
 
         status = workflow_job.status
-        if not workflow_job.running():
+        if not workflow_job.running:
             print_warn("Job is not in running state. Nothing to watch.")
             ctx.invoke(view)
             return
@@ -567,7 +567,7 @@ def watch(ctx, output):
                 if check_for_broken_job(workflow_job):
                     return
 
-        if workflow_job.running():
+        if workflow_job.running:
             import curses
 
             stdscr = curses.initscr()
@@ -576,7 +576,7 @@ def watch(ctx, output):
                 stdscr.clear()
                 stdscr.addstr("\nJob %s is running." % workflow_job.job_id)
                 n = 0
-                while workflow_job.running():
+                while workflow_job.running:
                     stdscr.addstr(".")
                     time.sleep(1.0)
                     workflow_job.refresh()
